@@ -3,8 +3,8 @@
 != Test program for "gt4_history_nmlinfo" 
 !
 ! Authors::   Yasuhiro MORIKAWA
-! Version::   $Id: gt4_history_nmlinfo_test.f90,v 1.16 2008-08-10 16:37:39 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20080810 $
+! Version::   $Id: gt4_history_nmlinfo_test.f90,v 1.17 2008-08-12 10:53:30 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20080812 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2007. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -26,7 +26,8 @@ program gt4_history_nmlinfo_test
     & HstNmlInfoAdd, HstNmlInfoDelete, HstNmlInfoResetDefault, &
     & HstNmlInfoInquire, HstNmlInfoAssocGtHist, &
     & HstNmlInfoOutputStepDisable, HstNmlInfoOutputStep, &
-    & HstNmlInfoOutputValid, HstNmlInfoNames, HstNmlInfoAllVarIniCheck, &
+    & HstNmlInfoOutputValid, HstNmlInfoNames, HstNmlInfoGetNames, &
+    & HstNmlInfoAllVarIniCheck, &
     & HstNmlInfoSetValidName, HstNmlInfoAllNameValid
   use gt4_history, only: GT_HISTORY, HistoryInitialized, HistoryCreate, &
     & HistoryAddVariable, HistoryPut, HistoryClose
@@ -44,7 +45,7 @@ program gt4_history_nmlinfo_test
   !  Title of a experiment, name of model, sub-organ
   !-------------------------------------------------------------------
   character(*), parameter:: title = &
-    & 'gt4_history_nmlinfo_test $Name: gt4f90io-20080810 $ :: ' // &
+    & 'gt4_history_nmlinfo_test $Name: gt4f90io-20080812 $ :: ' // &
     & 'Test program of "gt4_history_nmlinfo" module'
   character(*), parameter:: source = &
     & 'gtool4 project ' // &
@@ -525,12 +526,16 @@ continue
   !  names ƥ
   !  "names" test
   !-------------------------------------------------------------------
-  call HstNmlInfoNames( gthstnml06, & ! (in)
-    & varnames_array, err )           ! (out)
+  call HstNmlInfoGetNames( gthstnml06, & ! (in)
+    & varnames_array, err )              ! (out)
 
-  call AssertEqual( '"names" test 1-1', &
+  call AssertEqual( '"GetNames" test 1-1', &
     & answer = .true., check = err )
 
+  varnames = HstNmlInfoNames( gthstnml06 )
+  call AssertEqual( '"Names" test 1-1', &
+    & answer = '', check = varnames )
+
   call HstNmlInfoCreate( &
     & gthstnml = gthstnml06, & ! (out)
     & interval_value = 3.0, &  ! (in)
@@ -558,13 +563,17 @@ continue
 
   call HstNmlInfoPutLine( gthstnml = gthstnml06 ) ! (in)
 
-  call HstNmlInfoNames( gthstnml06, & ! (in)
+  call HstNmlInfoGetNames( gthstnml06, & ! (in)
     & varnames_array )                ! (out)
 
-  call AssertEqual( '"names" test 1-2', &
+  call AssertEqual( '"GetNames" test 1-2', &
     & answer = (/ 'Data1', 'Data2', 'Data4', 'Data5' /), check = varnames_array )
   deallocate( varnames_array )
 
+  varnames = HstNmlInfoNames( gthstnml06 )
+  call AssertEqual( '"Names" test 1-2', &
+    & answer = 'Data1,Data2,Data4,Data5', check = varnames )
+
   call HstNmlInfoClose( gthstnml = gthstnml06 ) ! (inout)
 
   !-------------------------------------------------------------------
@@ -589,7 +598,7 @@ continue
 
   call HstNmlInfoPutLine( gthstnml = gthstnml07 ) ! (in)
 
-  call HstNmlInfoNames( gthstnml07, & ! (in)
+  call HstNmlInfoGetNames( gthstnml07, & ! (in)
     & varnames_array )                ! (out)
 
   call AssertEqual( '"ResetDefault" test 1-1', &
@@ -634,7 +643,7 @@ continue
 
   call HstNmlInfoPutLine( gthstnml = gthstnml08 ) ! (in)
 
-  call HstNmlInfoNames( gthstnml08, & ! (in)
+  call HstNmlInfoGetNames( gthstnml08, & ! (in)
     & varnames_array )                ! (out)
 
   call AssertEqual( 'multiple variables handling test 1-1', &
@@ -647,7 +656,7 @@ continue
 
   call HstNmlInfoPutLine( gthstnml = gthstnml08 ) ! (in)
 
-  call HstNmlInfoNames( gthstnml08, & ! (in)
+  call HstNmlInfoGetNames( gthstnml08, & ! (in)
     & varnames_array )                ! (out)
 
   call AssertEqual( 'multiple variables handling test 1-1', &
